@@ -1,14 +1,10 @@
 package Net::Works;
-$Net::Works::VERSION = '0.20';
+
+use strict;
+use warnings;
 use 5.010000;
 
-# This is a hack to let us test code that requires a specific Net::Works
-# version against the Net-Works git repo code, but without actually setting
-# the $VERSION variable.
-BEGIN {
-    $Net::Works::{VERSION} = \99
-        unless exists $Net::Works::{VERSION};
-}
+our $VERSION = '0.21';
 
 1;
 
@@ -24,7 +20,7 @@ Net::Works - Sane APIs for IP addresses and networks
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 DESCRIPTION
 
@@ -114,7 +110,7 @@ Olaf Alders <oalders@wundercounter.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alexander Hartmaier Gregory Oschwald TJ Mather William Stevenson
+=for stopwords Alexander Hartmaier Dave Rolsky Greg Oschwald TJ Mather William Stevenson
 
 =over 4
 
@@ -124,7 +120,11 @@ Alexander Hartmaier <abraxxa@cpan.org>
 
 =item *
 
-Gregory Oschwald <oschwald@gmail.com>
+Dave Rolsky <drolsky@maxmind.com>
+
+=item *
+
+Greg Oschwald <goschwald@maxmind.com>
 
 =item *
 
@@ -138,7 +138,7 @@ William Stevenson <wstevenson@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by MaxMind, Inc..
+This software is copyright (c) 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
