@@ -1,8 +1,10 @@
 package Net::Works::Address;
-$Net::Works::Address::VERSION = '0.20';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.21';
+
 use Carp qw( confess );
 use Math::Int128 0.06 qw( uint128 uint128_to_hex uint128_to_number );
 use Net::Works::Types qw( PackedBinary Str );
@@ -125,7 +127,7 @@ sub as_bit_string {
     if ( $self->version == 6 ) {
         my $hex = uint128_to_hex( $self->as_integer() );
         my @ha  = $hex =~ /.{8}/g;
-        return join '', map { sprintf( '%032b', hex($_) ) } @ha;
+        return join q{}, map { sprintf( '%032b', hex($_) ) } @ha;
     }
     else {
         return sprintf( '%032b', $self->as_integer() );
@@ -191,7 +193,7 @@ Net::Works::Address - An object representing a single IP (4 or 6) address
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -335,7 +337,7 @@ Olaf Alders <oalders@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by MaxMind, Inc..
+This software is copyright (c) 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
